@@ -76,9 +76,7 @@ gboolean key_press_cb(GtkWidget* widget, GdkEventKey* event, HildonWindow* windo
 }
 
 gboolean long_tap(GtkWidget* widget, gpointer data) {
-	g_assert(data);
-	AppData* appdata = (AppData*) data;
-	g_signal_emit_by_name(appdata->window, "delete_event");
+	gtk_main_quit();
 	return TRUE;
 }
 
