@@ -219,6 +219,15 @@ void interpret_and_set_speed(gdouble speed) {
 	 */
 	speed *= conversion[unit];
 
+	/* we need to limit the speed down to
+	 * less than 1000 whatever or else hell
+	 * breaks loose in the form of assert
+	 */
+	if(!(fabs(speed) < 1000)) {
+	    g_print("Ahem, may I suggest to limit the speed (%f) a bit, Sir.\n", speed);
+	    speed = 0;
+	}
+
 	/* Convert float to a 6 digits (including dot) wide
 	 * string with leading zeros. After conversion
 	 * the speed looks like:
